@@ -23,6 +23,8 @@ $this->SetPreference('dublin_title',
 		     (isset($params['dublin_title'])?'1':'0'));
 $this->SetPreference('opengraph_title',
 		     (isset($params['opengraph_title'])?'1':'0'));
+$this->SetPreference('tweetme_title',
+		     (isset($params['tweetme_title'])?'1':'0'));
 
 $this->SetPreference('touchicon_title', $params['touchicon_title']);
 $this->SetPreference('fullscreen_title', $params['fullscreen_title']);
@@ -38,14 +40,21 @@ $this->SetPreference('scalable_title', $params['scalable_title']);
 $this->SetPreference('publisher_title', $params['publisher_title']);
 $this->SetPreference('contributor_title', $params['contributor_title']);
 $this->SetPreference('relation_title', $params['relation_title']);
+$this->SetPreference('email_title', $params['email_title']);
+$this->SetPreference('phone_title', $params['phone_title']);
+$this->SetPreference('fax_title', $params['fax_title']);
+$this->SetPreference('street_title', $params['street_title']);
 $this->SetPreference('location_title', $params['location_title']);
 $this->SetPreference('region_title', $params['region_title']);
+$this->SetPreference('postcode_title', $params['postcode_title']);
+$this->SetPreference('country_title', $params['country_title']);
 $this->SetPreference('latitude_title', $params['latitude_title']);
 $this->SetPreference('longitude_title', $params['longitude_title']);
 $this->SetPreference('ogtype_title', $params['ogtype_title']);
 $this->SetPreference('ogimage_title', $params['ogimage_title']);
 $this->SetPreference('favicon_title', $params['favicon_title']);
 $this->SetPreference('favsize_title', $params['favsize_title']);
+$this->SetPreference('fbpage_title', $params['fbpage_title']);
 $this->SetPreference('fbadmin_title', $params['fbadmin_title']);
 $this->SetPreference('fbapp_title', $params['fbapp_title']);
 
