@@ -89,6 +89,7 @@ $lang['compatible_7'] = 'IE 7';
 $lang['compatible_8'] = 'IE 8';
 $lang['compatible_9'] = 'IE 9';
 $lang['compatible_edge'] = 'IE Edge';
+$lang['compatible_emulate7'] = 'Emulate IE 7';
 $lang['compatible_chrome'] = 'Chrome';
 $lang['additional_title'] = 'Additional content to appear in head';
 $lang['stylesheet_title'] = 'Include &#123;cms_stylesheet} tag';
@@ -211,7 +212,10 @@ $lang['changelog'] = '<ul>
 <li>Version 1.7.4.8 3 April 2012. Added favicon size option for use with multi-image ico files.</li>
 <li>Version 1.7.4.9 18 May 2012. Stripping out of whitespace from descriptions added.</li>
 <li>Version 1.7.5 21 June 2012. Bug fix for 1.11 compatability.</li>
-<li>Version 1.7.6 21 June 2012. Additional optional meta tags added, Street, Postalcode, Country, Email, Telephone, Fax, Facebook page ID and Tweetme title. Minor bug fixes.</li></ul>';
+<li>Version 1.7.6 4 July 2012. Additional optional meta tags added, Street, Postalcode, Country, Email, Telephone, Fax, Facebook page ID and Tweetme title. Minor bug fixes.</li>
+<li>Version 1.7.6.1 11 July 2012. Added IE7 Emulate option to X-UA-Compatible tag.</li>
+<li>Version 1.7.7 9 October 2012. Additional HTML block now accepts smarty.</li>
+<li>Version 1.7.8 6 November 2012. Fixed issue where canonical link for news articles showed default detail page URL rather than news story URL.</li></ul>';
 $lang['help'] = '<h3>What Does This Do?</h3>
 <p>This module adds the ability to include additional Meta data, Analytics tracking code and other useful SEO information. It can also be used to generate Doctype and Head tags, replacing the entire head of your document.</p>
 <h3>How Do I Use It</h3>
